<?php declare(strict_types = 1);

// spell-check-ignore: DBACCESS TABLENAME abc abcdefghijklmnopqrstuvwxyz condname1 ctx dat dblwr ddse endswithspace fil haha hehe hoho lsn pri testrole testuser wp xyzzy 0every BQAAAA DRAUGR DUP FIL TRG VÐƷWİ aaa aaaaaa abcd asd attr4 azundris badvar bbbbbb fvar idx ivar loaddata5 maste mv mvi nosuchvar º Æ Ö Γåô Γê Γò Γòí ツ
// spell-check-ignore: switc acces é ü тест

namespace SqlFtw\Tests\Mysql\Data;

use SqlFtw\Tests\Mysql\Valid;

trait KnownFailures
{

    /** @var array<string, Valid::*> */
    private static array $knownFailures = [
        // false negatives -------------------------------------------------------------------------------------------------------------------------------------------------------------

        // encoding
        "DROP TABLE IF EXISTS `abc\xFFdef`;" => Valid::YES,
        "CREATE TABLE `abc\xFFdef` (i int);" => Valid::YES,
        "INSERT INTO `abc\xFFdef` VALUES (1);" => Valid::YES,
        "INSERT INTO abc\xFFdef VALUES (2);" => Valid::YES,
        "SELECT * FROM `abc\xFFdef`;" => Valid::YES,
        "SELECT * FROM abc\xFFdef;" => Valid::YES,
        "DROP TABLE `abc\xFFdef`;" => Valid::YES,

        // persist vs DEFAULT
        "SET PERSIST_ONLY innodb_data_file_path = DEFAULT;" => Valid::YES,
        "SET PERSIST_ONLY pid_file = DEFAULT;" => Valid::YES,

        // qualified column name
        'create table t1 (t1.index int)' => Valid::YES,
        'create table t1(t1.name int)' => Valid::YES,
        'create table t2(test.t2.name int)' => Valid::YES,
        // "REVOKE <role>" has no "ON"
        'REVOKE system_user_role ON *.* FROM non_sys_user' => Valid::YES,
        // index without a name
        'create index on edges (s)' => Valid::YES,
        'create index on edges (e)' => Valid::YES,
        'CREATE INDEX ON t1(a)' => Valid::YES,
        'CREATE INDEX ON t1 (col1, col2)' => Valid::YES,
        // pseudo-replica mode trickery
        "SET @@session.sql_mode=1436549152;" => Valid::YES,
        // error ignored...
        "-- error ER_BAD_FIELD_ERROR\nSET @@character_set_connection = utf8 + latin2;" => Valid::YES,
        "-- error ER_BAD_FIELD_ERROR\nSET @@character_set_client = utf8 + latin2;" => Valid::YES,
        "-- error ER_BAD_FIELD_ERROR\nSET @@character_set_database = utf8 + latin2;" => Valid::YES,
        "-- error ER_BAD_FIELD_ERROR\nSET @@character_set_filesystem = utf8 + latin2;" => Valid::YES,
        "-- error ER_BAD_FIELD_ERROR\nSET @@character_set_results = utf8 + latin2;" => Valid::YES,
        "-- error ER_BAD_FIELD_ERROR\nSET @@character_set_server = utf8 + latin2;" => Valid::YES,
        "-- error ER_BAD_FIELD_ERROR\nSET @@collation_connection = latin7_general_ci + latin7_general_cs;" => Valid::YES,
        "-- error ER_BAD_FIELD_ERROR\nSET @@collation_database = latin7_general_ci + latin7_general_cs;" => Valid::YES,
        "-- error ER_BAD_FIELD_ERROR\nSET @@collation_server = latin7_general_ci + latin7_general_cs;" => Valid::YES,
        "-- error ER_BAD_FIELD_ERROR\nSET @@lc_time_names = en_US | en_GB ;" => Valid::YES,
        "-- error ER_ILLEGAL_PRIVILEGE_LEVEL\nREVOKE DYNAMIC_PRIV1, DYNAMIC_PRIV2 ON wl14690.* FROM unknown_user IGNORE UNKNOWN USER;" => Valid::YES,
        "-- error ER_ILLEGAL_PRIVILEGE_LEVEL\nREVOKE DYNAMIC_PRIV1, DYNAMIC_PRIV2 ON wl14690.* FROM u1;" => Valid::YES,
        // collides with ignored "ER_INVALID_DEFAULT"
        "-- error ER_INVALID_DEFAULT_UTF8MB4_COLLATION\nSET @@default_collation_for_utf8mb4 = latin2_general_ci;" => Valid::YES,
        // depends on "SELECT ... INTO @space_id;"
        "set global innodb_fil_make_page_dirty_debug = @space_id;" => Valid::YES,
        "SET SESSION innodb_interpreter = CONCAT('find_fil_page_lsn ', @space_id, ' 0');" => Valid::YES,
        "SET SESSION innodb_interpreter = @cmd;" => Valid::YES,
        "SET SESSION innodb_interpreter = CONCAT('dblwr_force_crash ', @space_id, ' 0');" => Valid::YES,
        "-- error 2013\nSET SESSION innodb_interpreter = CONCAT('make_page_dirty ', @space_id, ' 0');" => Valid::YES,
        "SET global innodb_fil_make_page_dirty_debug=@space_id;" => Valid::YES,
        "-- error CR_SERVER_LOST\nSET GLOBAL innodb_fil_make_page_dirty_debug = @space_id;" => Valid::YES,
        // 63bit limit
        "set global flush_time=cast(-1 as unsigned int);" => Valid::YES,
        "set max_join_size=cast(-1 as unsigned int);" => Valid::YES,
        "set global sync_relay_log=cast(-1 as unsigned int);" => Valid::YES,
        "set global sync_relay_log_info=cast(-1 as unsigned int);" => Valid::YES,
        "set global sync_source_info=cast(-1 as unsigned int);" => Valid::YES,
        "set global thread_cache_size=cast(-1 as unsigned int);" => Valid::YES,
        // session var should be returned when global does not exist
        "SELECT @@global.rbr_exec_mode;" => Valid::YES,
        // "table name not allowed here"
        "-- error ER_TABLENAME_NOT_ALLOWED_HERE\n(SELECT a FROM t1 LIMIT 1) ORDER BY t1.a;" => Valid::YES,
        "-- error ER_TABLENAME_NOT_ALLOWED_HERE\n((SELECT a FROM t1 LIMIT 1)) ORDER BY t1.a;" => Valid::YES,
        "-- error ER_TABLENAME_NOT_ALLOWED_HERE\n(SELECT a FROM t1 LIMIT 1) UNION ALL (SELECT 2) ORDER BY t1.b;" => Valid::YES,
        "-- error ER_TABLENAME_NOT_ALLOWED_HERE\n(SELECT a FROM t1 LIMIT 1) UNION ALL ((SELECT 2)) ORDER BY t1.b;" => Valid::YES,
        "-- error ER_TABLENAME_NOT_ALLOWED_HERE\n(SELECT a FROM t1 LIMIT 1) UNION ALL (SELECT a FROM t1 ORDER BY a LIMIT 2)\n  ORDER BY t1.b;" => Valid::YES,
        // "rows" is already a reserved word
        "--echo the result rows with missed equal to NULL should count all rows (160000)\n--echo the other rows are the failed lookups and there should not be any such\nselect if(isnull(t1.a),t2.a,NULL) missed, count(*) rows from t2 left join t1 on t1.a=t2.a group by if(isnull(t1.a),t2.a,NULL)" => Valid::YES,
        "--echo the left join below should result in scanning t2 and do pk lookups in t1\n--replace_column 10 # 11 #\nexplain select if(isnull(t1.a),t2.a,NULL) missed, count(*) rows from t2 left join t1 on t1.a=t2.a group by if(isnull(t1.a),t2.a,NULL)" => Valid::YES,
        "-- error ER_NO_SYSTEM_TABLE_ACCESS\n  CREATE PROCEDURE ddse_access() DROP TABLE mysql.innodb_index_stats(i INTEGER);" => Valid::YES,
        // behavior differs in plain sql and in procedure
        "create event e22830_1 on schedule every 1 hour do\nbegin\n  call p22830_wait();\n  alter event e22830_1 on schedule every (select 8 from dual) hour;\nend|" => Valid::YES,
        "create event e22830_2 on schedule every 1 hour do\nbegin\n  call p22830_wait();\n  alter event e22830_2 on schedule every (select 8 from t1) hour;\nend|" => Valid::YES,
        "create event e22830_3 on schedule every 1 hour do\nbegin\n  call p22830_wait();\n  alter event e22830_3 on schedule every f22830() hour;\nend|" => Valid::YES,
        "create event e22830_4 on schedule every 1 hour do\nbegin\n  call p22830_wait();\n  alter event e22830_4 on schedule every (select f22830() from dual) hour;\nend|" => Valid::YES,
        "-- error ER_WRONG_VALUE\nCREATE EVENT new_event ON SCHEDULE AT (SELECT \"every day\") DO SELECT 1;" => Valid::YES,
        // actually a syntax error
        "-- error ER_SP_UNDECLARED_VAR\nGET DIAGNOSTICS var;" => Valid::YES,
        "-- error ER_SP_UNDECLARED_VAR\nCREATE PROCEDURE p1()\nBEGIN\n  GET DIAGNOSTICS var;\nEND|" => Valid::YES,
        "-- error ER_SP_UNDECLARED_VAR\nGET DIAGNOSTICS CONDITION 1 var;" => Valid::YES,
        "-- error ER_SP_UNDECLARED_VAR\nCREATE PROCEDURE p1()\nBEGIN\n  GET DIAGNOSTICS CONDITION 1 var;\nEND|" => Valid::YES,
        "-- error ER_SP_UNDECLARED_VAR\nCREATE PROCEDURE p1()\nBEGIN\n  DECLARE var CONDITION FOR SQLSTATE '12345';\n  GET DIAGNOSTICS CONDITION 1 var = NUMBER;\nEND|" => Valid::YES,
        "-- error ER_ILLEGAL_PRIVILEGE_LEVEL\nGRANT xyzzy ON PROCEDURE B30628160.p1 TO B30628160@localhost;" => Valid::YES,
        "-- error ER_DBACCESS_DENIED_ERROR\ncreate view information_schema.v1;" => Valid::YES,
        "-- error ER_SP_UNDECLARED_VAR\nCREATE PROCEDURE p1()\nBEGIN\n  DECLARE var CONDITION FOR SQLSTATE '01001';\n  GET DIAGNOSTICS CONDITION 1 var = NUMBER;\nEND|" => Valid::YES,
        "-- error ER_CHECK_NOT_IMPLEMENTED\nCREATE TABLE t1 (f1 INT NOT NULL) ENGINE=MyISAM ENCRYPTION='w';" => Valid::YES,
        "CREATE PROCEDURE sp1( )\nBEGIN\n    declare collate condition for sqlstate '02000';\n    declare exit handler for collate set @var2 = 1;\nEND//" => Valid::YES,
        "CREATE PROCEDURE h1 ()\nBEGIN\n    declare x1 int default 0;\n    BEGIN\n        declare condname1 condition for sqlstate '00000';\n      declare exit handler for condname1 set @x = 1;\n      set x1 = 1;\n      set x1 = 2;\n    END;\n    SELECT @x, x1;\nEND//" => Valid::YES,
        "CREATE PROCEDURE h1 ()\nBEGIN\n   DECLARE x1 INT DEFAULT 0;\n   BEGIN\n      DECLARE condname1 CONDITION FOR SQLSTATE '00000';\n      DECLARE EXIT HANDLER FOR SQLSTATE '00000' SET @x = 1;\n      SET x1 = 1;\n      SET x1 = 2;\n   END;\n   SELECT @x, x1;\nEND//" => Valid::YES,

        // misc
        "SET GLOBAL group_replication_single_primary_mode= -1;" => Valid::YES, // fuck you. your doc says BOOLEAN!
        "SET GLOBAL group_replication_single_primary_mode= 100;" => Valid::YES,
        "SET GLOBAL group_replication_enforce_update_everywhere_checks= -1;" => Valid::YES,
        "SET GLOBAL group_replication_enforce_update_everywhere_checks= 100;" => Valid::YES,

        // unresolved expressions
        "set @@global.binlog_checksum= IF(floor((rand()*1000)%2), \"CRC32\", \"NONE\");" => Valid::YES,
        "-- error ER_UNKNOWN_LOCALE\nset global LC_MESSAGES=convert((@@global.log_bin_trust_function_creators)\n    using cp1250);" => Valid::YES,
        "-- error ER_WRONG_ARGUMENTS\nSET INSERT_ID= NAME_CONST(a, a);" => Valid::YES,
        "set session_track_system_variables=f();" => Valid::YES,
        "set @@session.autocommit=t1_min(), @@session.autocommit=t1_max(),\n    @@session.autocommit=t1_min(), @@session.autocommit=t1_max(),\n    @@session.autocommit=t1_min(), @@session.autocommit=t1_max();" => Valid::YES,

        // storage engine dependent
        "create table t1 (v varchar(65536));" => Valid::YES,
        "CREATE TABLE t (a VARCHAR(1000000)) ENGINE = InnoDB;" => Valid::YES,
        "-- error ER_ALTER_OPERATION_NOT_SUPPORTED_REASON\nALTER TABLE t2 ALGORITHM=INPLACE, CHANGE COLUMN fk fk VARCHAR(99999);" => Valid::YES,
        "-- error ER_BLOB_KEY_WITHOUT_LENGTH\nALTER TABLE t2 ALGORITHM=INPLACE, CHANGE COLUMN fk fk VARCHAR(99999);" => Valid::YES,

        // strange engine behavior
        "CREATE TABLE t2 (a char(255), b varbinary(70000), c varchar(70000000));" => Valid::YES,

        // WTF double_write
        "-- error ER_WRONG_ARGUMENTS\nSET @@GLOBAL.innodb_doublewrite=4;" => Valid::YES,
        "-- error ER_WRONG_ARGUMENTS\nSET @@GLOBAL.innodb_doublewrite=5;" => Valid::YES,
        "SET @@GLOBAL.innodb_doublewrite=4;" => Valid::YES,
        "SET @@GLOBAL.innodb_doublewrite=5;" => Valid::YES,


        // false positives -------------------------------------------------------------------------------------------------------------------------------------------------------------

        // test artifacts
        "-- error ER_WRONG_VALUE_FOR_VAR\n\n\nSET @@global.rpl_semi_sync_replica_enabled = @start_global_value;" => Valid::NO,
        "-- error ER_UNSUPPORTED_SQL_MODE\nINSERT INTO t1 VALUES (1);" => Valid::NO,
        "-- error ER_UNSUPPORTED_SQL_MODE\nCALL p1;" => Valid::NO,
        "-- error ER_GLOBAL_VARIABLE\nSET test_component.bool_sys_var=1;" => Valid::NO,
        "-- error ER_GLOBAL_VARIABLE\nSET test_component.enum_sys_var=\"LOW\";" => Valid::NO,
        "-- error 0,ER_UNKNOWN_SYSTEM_VARIABLE\nset global ndb_dbg_check_shares=1;" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT test_set_system_variable_string(0, \"the_meaning_of_life\", \"42\", \"GLOBAL\");" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT test_set_system_variable_string(1, \"the_meaning_of_life\", \"42\", \"GLOBAL\");" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSELECT test_set_system_variable_string(0, \"super_read_only\", \"gizmo\", \"GLOBAL\");" => Valid::NO,
        "-- disable_query_log\n-- error 0,ER_UNKNOWN_SYSTEM_VARIABLE\nSET @innodb_change_buffering_debug_orig = @@innodb_change_buffering_debug;" => Valid::NO,
        "-- error ER_UNKNOWN_STORAGE_ENGINE\nCREATE TABLE t1 (c1 INT) ENGINE= ARCHIVE;" => Valid::NO,
        "-- error ER_UNKNOWN_STORAGE_ENGINE\nCREATE TEMPORARY TABLE t1 (c1 INT) ENGINE= ARCHIVE;" => Valid::NO,
        "-- error ER_UNKNOWN_STORAGE_ENGINE\nALTER TABLE t1 ENGINE= ARCHIVE;" => Valid::NO,
        "-- error ER_UNKNOWN_STORAGE_ENGINE\nCREATE TABLE t1(a int) ENGINE=ARCHIVE;" => Valid::NO,
        "-- error ER_UNKNOWN_STORAGE_ENGINE\nCREATE TABLE t1(a int) ENGINE=BLACKHOLE;" => Valid::NO,
        "-- error ER_UNKNOWN_STORAGE_ENGINE\nDROP TABLE t1;" => Valid::NO,
        "-- error ER_UNKNOWN_STORAGE_ENGINE\ncreate table t1 (id int) engine=FEDERATED;" => Valid::NO,
        "-- error ER_UNKNOWN_STORAGE_ENGINE\nalter table t1 engine=FEDERATED;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\ncall test_signal() $$" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\ncall test_signal(\"Parameter string\", NULL) $$" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\ncall test_signal(NULL, 1234) $$" => Valid::NO,
        "-- error 2\ncall peter_p3() $$" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\ncall test_signal $$" => Valid::NO,
        "-- error ER_STMT_NOT_ALLOWED_IN_SF_OR_TRG\nselect f1(0)|" => Valid::NO,
        "-- error ER_STMT_NOT_ALLOWED_IN_SF_OR_TRG\nselect f1(f1(0))|" => Valid::NO,
        "-- error ER_STMT_NOT_ALLOWED_IN_SF_OR_TRG\nselect f1(f1(f1(0)))|" => Valid::NO,
        "-- error ER_UNSUPPORTED_PS\ncall p1()|" => Valid::NO,
        "-- error ER_SP_WRONG_NO_OF_FETCH_ARGS\ncall p()|" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nEXECUTE s USING @x;" => Valid::NO,
        "-- error 40000\ncall bigError();" => Valid::NO,
        "-- error ER_WRONG_VALUE\ncall p_16();" => Valid::NO,
        "-- error 0,ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL mysqlx_zstd_default_compression_level=1;" => Valid::NO, // depends on lib version
        "-- error 0,ER_WRONG_VALUE_FOR_VAR\nSET @@global.mysqlx_zstd_default_compression_level=2;" => Valid::NO,
        "-- error 0,ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL mysqlx_zstd_default_compression_level=-1;" => Valid::NO,
        "-- error 0,ER_WRONG_VALUE_FOR_VAR\nSET @@global.mysqlx_zstd_default_compression_level=-2;" => Valid::NO,
        "-- error 0,ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL mysqlx_zstd_max_client_compression_level=1;" => Valid::NO,
        "-- error 0,ER_WRONG_VALUE_FOR_VAR\nSET @@global.mysqlx_zstd_max_client_compression_level=2;" => Valid::NO,
        "-- error 0,ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL mysqlx_zstd_max_client_compression_level=-1;" => Valid::NO,
        "-- error 0,ER_WRONG_VALUE_FOR_VAR\nSET @@global.mysqlx_zstd_max_client_compression_level=-2;" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT @@global.dragnet.log_error_filter_rules;" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSET @@global.dragnet.log_error_filter_rules='IF err_symbol==\"ER_STARTUP\" THEN drop.';" => Valid::NO,
        "-- error ER_CTE_RECURSIVE_FORBIDDEN_JOIN_ORDER\nEXECUTE ps;" => Valid::NO,
        // let's use magic in tests...
        "-- error ER_INCORRECT_GLOBAL_LOCAL_VAR\nSELECT test_set_system_variable_default(0, NULL, \"admin_port\", \"GLOBAL\");" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT test_set_system_variable_default(1, NULL, \"the_meaning_of_life\", \"GLOBAL\");" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT test_set_system_variable_default(0, NULL, \"the_meaning_of_life\", \"GLOBAL\");" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSELECT test_set_system_variable_unsigned_integer(0, NULL, \"super_read_only\", 10000, \"GLOBAL\");" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSELECT test_set_system_variable_unsigned_integer(0, NULL, \"block_encryption_mode\", 10000, \"GLOBAL\");" => Valid::NO,
        "-- error ER_INCORRECT_GLOBAL_LOCAL_VAR\nSELECT test_set_system_variable_unsigned_integer(0, NULL, \"admin_port\", 10000, \"GLOBAL\");" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT test_set_system_variable_unsigned_integer(1, NULL, \"the_meaning_of_life\", 42, \"GLOBAL\");" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT test_set_system_variable_unsigned_integer(0, NULL, \"the_meaning_of_life\", 42, \"GLOBAL\");" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSELECT test_set_system_variable_signed_integer(0, NULL, \"super_read_only\", 10000, \"GLOBAL\");" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSELECT test_set_system_variable_signed_integer(0, NULL, \"block_encryption_mode\", 10000, \"GLOBAL\");" => Valid::NO,
        "-- error ER_INCORRECT_GLOBAL_LOCAL_VAR\nSELECT test_set_system_variable_signed_integer(0, NULL, \"admin_port\", 10000, \"GLOBAL\");" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT test_set_system_variable_signed_integer(1, NULL, \"the_meaning_of_life\", 42, \"GLOBAL\");" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT test_set_system_variable_signed_integer(0, NULL, \"the_meaning_of_life\", 42, \"GLOBAL\");" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSELECT test_set_system_variable_string(0, NULL, \"super_read_only\", \"gizmo\", \"GLOBAL\");" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT test_set_system_variable_string(1, NULL, \"the_meaning_of_life\", \"42\", \"GLOBAL\");" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT test_set_system_variable_string(0, NULL, \"the_meaning_of_life\", \"42\", \"GLOBAL\");" => Valid::NO,
        "-- error ER_COMMAND_SERVICE_BACKEND_FAILED\nSELECT test_command_service_udf(\"SELECT * FROM mysql.plugin ORDER BY name\");" => Valid::NO,
        "-- error ER_COMMAND_SERVICE_BACKEND_FAILED\nSELECT test_mysql_command_services_udf(\"SELECT * FROM information_schema.innodb_tables\");" => Valid::NO,
        "-- error ER_COMMAND_SERVICE_BACKEND_FAILED\nSELECT test_mysql_command_services_udf(\"SELECT * FROM mysql.plugin ORDER BY name\");" => Valid::NO,
        // sql_mode vs escaping
        "INSERT INTO t1 VALUES (\"1\\\"\"), (\"\\\"2\");" => Valid::NO,
        // no info on charset/engine ids. this is runtime error
        "-- error ER_UNKNOWN_CHARACTER_SET\nSET CHARACTER_SET_CLIENT=17;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nset session character_set_client=2048;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nset session character_set_connection=2048;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nset session character_set_database=2048;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nset session character_set_filesystem=2048;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nset session character_set_results = 2048;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nset session character_set_server=2048;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nset character_set_client=9999999;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nSET @@character_set_client = 100;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nSET @@character_set_connection = 100;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nSET @@character_set_database = 100;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nSET @@character_set_filesystem = 100;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nSET @@character_set_results = 100;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nSET @@character_set_server = 100;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nSET @@global.character_set_client = 100;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nSET @@global.character_set_connection = 100;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nSET @@global.character_set_database = 100;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nSET @@global.character_set_filesystem = 100;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nSET @@global.character_set_results = 100;" => Valid::NO,
        "-- error ER_UNKNOWN_CHARACTER_SET\nSET @@global.character_set_server = 100;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.internal_tmp_mem_storage_engine = 123;" => Valid::NO,
        // multibyte not supported?
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@character_set_client = ucs2;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@character_set_client = utf16;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@character_set_client = utf32;" => Valid::NO,
        // ¯\_(ツ)_/¯
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.ft_boolean_syntax = '+-> <()~*:\"\"&|';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.ft_boolean_syntax = '0';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.ft_boolean_syntax = '1 -><()~*:11&|';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.ft_boolean_syntax = '# -><()~*:11&1';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.ft_boolean_syntax = '1234567890ABCD';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.ft_boolean_syntax = '+-> <((~*:\".&|';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.ft_boolean_syntax = ' ';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.ft_boolean_syntax = ENABLE;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.ft_boolean_syntax = 'IGNORE';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.ft_boolean_syntax = ON;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global ft_boolean_syntax='@ -><()~*:\"\"@|';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global ft_boolean_syntax='+ -><()~*:\"\"@!|';" => Valid::NO,
        // implement gtid values
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.gtid_purged= '         -+11111111-1111-1111-1111-111111111111:9';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.gtid_purged= '         +-11111111-1111-1111-1111-111111111111:9';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL group_replication_group_name= \"8a94f357-aab4-11df-86ab-invalid\";" => Valid::NO,
        // special rules for dynamic changes
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_commit_concurrency=0;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_commit_concurrency=1;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_commit_concurrency=42;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.innodb_commit_concurrency = 1;" => Valid::NO,
        "-- error ER_INCORRECT_GLOBAL_LOCAL_VAR\nSET @@GLOBAL.innodb_doublewrite=off;" => Valid::NO,
        "-- error ER_INCORRECT_GLOBAL_LOCAL_VAR\nSET @@GLOBAL.innodb_doublewrite=on;" => Valid::NO,
        // strict type handling
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_queries_not_using_indexes= 'true';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_queries_not_using_indexes= @badvar;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_slow_admin_statements= 'true';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_slow_admin_statements= @badvar;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_statements_unsafe_for_binlog= 'true';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_statements_unsafe_for_binlog= @badvar;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.offline_mode= 'true';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@session.unique_checks = \"True\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@session.unique_checks = \"False\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET sql_quote_show_create= _binary x'5452c39c45';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET sql_quote_show_create= _utf8 x'5452c39c45';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET sql_quote_show_create=_latin1 x'5452dc45';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nWITH cte1 AS\n(SELECT(replace(md5(0x9025c5c7),\n                    convert((1) using utf8),\n                    (!(cast((555) AS char(20)))))) AS a1 FROM t0022)\nSELECT cte1.a1\nFROM cte1 WHERE cte1.a1 = from_unixtime(1537000917);" => Valid::NO,
        // special format
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_ft_aux_table='Salmon';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_ft_aux_table =@a;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_ft_server_stopword_table='Salmon';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset session innodb_ft_user_stopword_table='Salmon';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset @@session.innodb_ft_user_stopword_table='Salmon';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_ft_user_stopword_table='Salmon';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_monitor_enable = aaa;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_monitor_enable = \"%lock*\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_monitor_enable=\"\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_monitor_enable=\"_\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_monitor_enable =0xee;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_monitor_disable =0xed;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.innodb_redo_log_archive_dirs=\"/dir1\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.innodb_redo_log_archive_dirs=\":\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.innodb_redo_log_archive_dirs=\"l1:\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.innodb_redo_log_archive_dirs=\":d1;;\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.innodb_redo_log_archive_dirs=\":d1;d2\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.innodb_redo_log_archive_dirs=\"l1:d1;l2:\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.innodb_redo_log_archive_dirs=\"l1:d1;l2:;\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_tmpdir=repeat('a',1000);" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list=\"1234\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list=\"-10000,10001,MY-10002\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list=\"10000,-10001,MY-10002\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list=\"10000,10001,-MY-10002\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list=\",10000,10001,MY-10002\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list=\"10000,,10001,MY-10002\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list=\"10000,10001,MY-10002,\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list=\",\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list=\"10000 10001\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list= CONCAT(REPEAT(\"ER_PARSER_TRACE,\",509),\"ER_PARSER_TRACE\");" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list= CONCAT(REPEAT(\"10000,\", 509), \"11111\");" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list='10000.123';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list='MY-10000#$%';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list='999';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list='MY-999';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_suppression_list='25000';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_error_suppression_list='12345.124';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_error_suppression_list='12345e5';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_error_suppression_list=abcd;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_error_suppression_list='abcd';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_error_suppression_list=',';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_error_suppression_list=',10000,';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_error_suppression_list='10000,';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_error_suppression_list=',10000';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_error_suppression_list='10000,,10001';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_error_suppression_list=\"'10000'\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_error_suppression_list=CONCAT(\"'\",CONCAT('10000',\"'\"));" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_error_suppression_list=\"MY-0100000\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_output = -1;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_output = TAB;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_output = NIL;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_output = 'FIL';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_output = 'T';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_output = 'TABLE, FILE';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_output = ' TABLE,FILE';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_output = 0;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_output = 8;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_output = FALSE;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_output = 0;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset session optimizer_switch=\"index_merge\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset session optimizer_switch=\"foobar\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global optimizer_switch = 'e';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset optimizer_switch ='b';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset optimizer_switch = 0x6400ec62;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset optimizer_switch='default,index_merge';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset optimizer_switch='index_merge=index_merge';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset optimizer_switch='index_merge=on,but...';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset optimizer_switch='index_merge=';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset optimizer_switch='index_merge';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset optimizer_switch='on';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset optimizer_switch='index_merge=on,index_merge=off';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset optimizer_switch='index_merge_union=on,index_merge_union=default';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset optimizer_switch='default,index_merge=on,index_merge=off,default';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset session optimizer_trace=\"foobar\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset session optimizer_trace_features=\"foobar\";" => Valid::NO,
        "-- error ER_DUP_LIST_ENTRY\nSET @@global.session_track_system_variables= \"sql_mode,sql_mode\";" => Valid::NO,
        "-- error ER_DUP_LIST_ENTRY\nSET @@session.session_track_system_variables= \"sql_mode,sql_mode\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL mandatory_roles=\"foo,\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL mandatory_roles='``@`localhost`';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL innodb_ft_aux_table=\"test/t6\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_ft_server_stopword_table = \"not_defined\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_monitor_reset_all=0xe7;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_monitor_reset =0xe9;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_services=\";log_sink_internal\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_services=\"log_sink_internal; log_filter_internal\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_services=\"log_filter_internal;,log_sink_internal\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_services=\"log_filter_internal log_sink_internal\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_services=\"azundris\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_services=\"log_sink_buffer\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_error_services= \"log_filter_internal; log_sink_internal; log_filter_internal; log_sink_json\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL log_error_services= \"log_sink_internal; log_sink_internal\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_services=\"log_sink_internal; log_sink_internal\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.log_error_services=\"log_filter_dragnet; log_filter_dragnet\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='drop.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='ELSE drop.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='DRAUGR.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN set b==2.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF err_symbol=='ER_STARTUP THEN drop.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF err_symbol==ER_STARTUP' THEN drop.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF err_symbol=='ER_STARTUP\\\" THEN drop.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF err_symbol==\\\"ER_STARTUP' THEN drop.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF misc_cstring=='1' THEN drop.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF a=='1' THEN set misc_cstring:='abc'.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF EXISTS misc_cstring THEN drop.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF EXISTS foo THEN set component:=1.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF EXISTS foo THEN set component:=1..5.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF EXISTS foo THEN set prio:=1.5.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF err_symbol==ER_STARTUP\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF NOT field THEN action.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF err_symbol==ER_STARTUP THEN drop.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF err_code==\"ER_STARTUP\" THEN drop.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 AND b==3 THEN unset.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF EXISTS a>0 THEN drop.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF EXISTS a THEN drop';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF EXISTS field THEN AND.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF EXISTS field DROP.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN set.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN set b.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN set b:=.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN set :=2.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN drop';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF thread>=INFORMATION THEN drop.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF prio>=INFORMATION THEN set thread:=ERROR.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF prio>=NOUGAT THEN drop.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF prio>=9999 THEN throttle 1/1111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111 .\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF prio>=9999 THEN drop. IF EXISTS source_line THEN unset source_line. IF err_code == 001045 THEN throttle 1/1.1.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF prio>=9999 THEN throttle 111/604801.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF prio>=9999 THEN throttle 111/0.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=\"IF prio>=9999 THEN throttle 111/-1.\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN drop a.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN throttle a.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN throttle 1.5.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN throttle 1/b.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN throttle a/.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN throttle -1/2.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN throttle 0/2.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='ELSE.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 ELSE.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN drop ELSE drop ELSE drop.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN drop ELSE scream.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a==2 THEN drop ELSE.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF .';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF EXISTS a THEN.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF a!!b THEN drop.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules='IF EXISTS.';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules= REPEAT(\"IF prio>9 THEN drop. \", 1025);" => Valid::NO,
        "-- error 0,ER_WRONG_VALUE_FOR_VAR\nSET @@global.dragnet.log_error_filter_rules=@save_filters;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.syseventlog.facility= \"9\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.syseventlog.facility= \"local8\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.syseventlog.tag= \"path/like\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.event_scheduler = DISABLED;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET PERSIST event_scheduler=DISABLED;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL event_scheduler=DISABLED;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL event_scheduler=2;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.event_scheduler = 2;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSIGNAL SQLSTATE 'HY000' SET MYSQL_ERRNO = 65536;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSIGNAL SQLSTATE 'HY000' SET MYSQL_ERRNO = 99999;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSIGNAL SQLSTATE 'HY000' SET MYSQL_ERRNO = 4294967295;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSIGNAL SQLSTATE 'HY000' SET MYSQL_ERRNO = 0;" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nset lc_time_names=concat('de','+','DE');" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nset lc_time_names=-1;" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nset lc_time_names=111;" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nSET @@lc_time_names = 111;" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nSET @@session.lc_time_names=EE;" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nSET @@global.lc_time_names=EE;" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nSET @@lc_time_names = en_EN;" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nSET @@lc_time_names = US_en;" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nSET @@lc_time_names = -1;" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nSET @@lc_time_names = 'en US';" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nSET @@lc_time_names = 'enUS';" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nSET @@lc_time_names = ON;" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nSET @@global.lc_time_names = en_EN;" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nSET @@global.lc_time_names = US_en;" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nSET @@global.lc_time_names = -1;" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nSET @@global.lc_time_names = 'enUS';" => Valid::NO,
        "-- error ER_UNKNOWN_LOCALE\nSET @@global.lc_time_names = ON;" => Valid::NO,
        // file paths
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.keyring_file_data= '../../../../../bad_dir/bad_keyring_file_data/';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.keyring_file_data='/';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.keyring_file_data='/keyring/';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.keyring_file_data= 'MYSQL_test_invalid/dir/';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_tmpdir='wrong_value';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global innodb_tmpdir = @@global.datadir;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global general_log_file='/not existing path/log.master';" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL general_log_file= CONCAT('/not existing path/log.maste', 'r');" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL slow_query_log_file= CONCAT('/not existing path/log.maste', 'r');" => Valid::NO,
        "-- error ER_WRONG_VALUE\nCREATE TABLE t4 (a int, b text) TABLESPACE=innodb_file_per_table DATA DIRECTORY='test';" => Valid::NO,
        "-- error ER_WRONG_VALUE\ncreate table mysqltest.t9 (a int not null auto_increment, b char(16) not null, primary key (a)) \nengine=myisam index directory=\"not-hard-path\";" => Valid::NO,
        // some user restrictions; deprecated
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@session.max_delayed_threads = 1000;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@session.max_delayed_threads = 1;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@session.max_delayed_threads = 1025;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@session.max_delayed_threads = 16384;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@max_delayed_threads = 100000;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET max_delayed_threads = 1024;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@session.max_insert_delayed_threads = 1000;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@session.max_insert_delayed_threads = 1;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@session.max_insert_delayed_threads = 1025;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@session.max_insert_delayed_threads = 16384;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@max_insert_delayed_threads = 100000;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET max_insert_delayed_threads = 1024;" => Valid::NO,
        // WTF?
        "-- error ER_EMPTY_QUERY\n ;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.connection_control_min_connection_delay= 11000;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@global.connection_control_max_connection_delay= 10000;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@GLOBAL.group_replication_clone_threshold= 9223372036854775808;" => Valid::NO, // probably lying in doc about the limits...
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL group_replication_flow_control_min_quota= 1000;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL group_replication_flow_control_min_recovery_quota= 1000;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL group_replication_flow_control_max_quota= 1;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL group_replication_force_members= \"127.0.0.1:10000\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL group_replication_force_members= \"127.0.0.1:10001\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL group_replication_force_members= \"256.256.256.777:1234\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL group_replication_force_members= \"\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL group_replication_gtid_assignment_block_size= 9223372036854775808;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL group_replication_message_cache_size= 4294967296;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@GLOBAL.group_replication_member_weight= 100;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@GLOBAL.group_replication_recovery_compression_algorithms= \"ZLIB\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET @@GLOBAL.group_replication_recovery_compression_algorithms= \"ZSTD\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL GROUP_REPLICATION_COMMUNICATION_DEBUG_OPTIONS=\",,,\";" => Valid::NO, // set
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL GROUP_REPLICATION_COMMUNICATION_DEBUG_OPTIONS=\",,,,,\";" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL group_replication_single_primary_mode= TRUE;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL group_replication_enforce_update_everywhere_checks= TRUE;" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSET GLOBAL group_replication_allow_local_disjoint_gtids_join= ON;" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT @@GLOBAL.group_replication_allow_local_disjoint_gtids_join;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL group_replication_view_change_uuid = \"\";" => Valid::NO, // PERSIST_ONLY is ok
        "-- error 0,ER_WRONG_VALUE\nSELECT 1 FROM t1 WHERE (@b IN ( SELECT a FROM t1 )) = a;" => Valid::NO,
        "-- error 0\nALTER TABLE t1 algorithm=copy, ADD c CHAR(19);" => Valid::NO,
        // WTF?!
        "-- error ER_PARSE_ERROR\nselect hex(weight_string('a' as char(0)));" => Valid::NO,
        "-- error ER_PARSE_ERROR\nselect * from t1 where match b against ('+aaaaaa @bbbbbb' in boolean mode);" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT * FROM t1 WHERE MATCH(a) AGAINST(\"*\");" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT a FROM t1 WHERE MATCH (a) AGAINST (CONCAT(0x00, '\"', 'i', 'n', 'n', 'o', 'd', 'b', ' ', '$', 's', 't', 'o', 'r', 'a', 'g', 'e', '\"','@', '4', 0x00) IN BOOLEAN MODE);" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT b FROM t1 WHERE MATCH (b) AGAINST (CONCAT(0x00, '\"', 'i', 'n', 'n', 'o', 'd', 'b', ' ', '$', 's', 't', 'o', 'r', 'a', 'g', 'e', '\"','@', '4', 0x00) IN BOOLEAN MODE);" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT c FROM t1 WHERE MATCH (c) AGAINST (CONCAT(0x00, '\"', 'i', 'n', 'n', 'o', 'd', 'b', ' ', '$', 's', 't', 'o', 'r', 'a', 'g', 'e', '\"','@', '4', 0x00) IN BOOLEAN MODE);" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT ANY_VALUE(MATCH (a) AGAINST ('<' IN BOOLEAN MODE)), COUNT(*) FROM t;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nselect * from t1 where MATCH(a,b) AGAINST(\"+-VÐƷWİ\" IN BOOLEAN MODE);" => Valid::NO,
        "-- error ER_FUNCTION_NOT_DEFINED\nCREATE TABLE t2 (\n        id INT UNSIGNED AUTO_INCREMENT NOT NULL PRIMARY KEY,\n        title VARCHAR(200),\n\tFULLTEXT INDEX ft_title (title) WITH PARSER ngram\n) ENGINE=InnoDB DEFAULT CHARACTER SET gb2312 COLLATE gb2312_chinese_ci;" => Valid::NO,
        // debug (valid syntax, invalid circumstances)
        "-- error 0,ER_UNKNOWN_SYSTEM_VARIABLE\nSET @aux = @@session.debug;" => Valid::NO,
        "-- error ER_RESTART_SERVER_FAILED\nRESTART;" => Valid::NO,
        "-- error 1,1\nCREATE TABLE s.t (pk INTEGER PRIMARY KEY);" => Valid::NO,
        "-- error 2\ncall peter_p3();" => Valid::NO,
        "-- error 18\ncall test_signal;" => Valid::NO,
        "-- error 3\ncall test_signal;" => Valid::NO,
        "-- error 10000\n  call po_add_order_line (@my_po, 1, 999, 1);" => Valid::NO,
        "-- error 10000\n  call po_add_order_line (99, 1, 100, 1);" => Valid::NO,
        "-- error 10000\ncall po_create_order(\"M\", 7, @my_po);" => Valid::NO,
        "-- error ER_COND_ITEM_TOO_LONG\ncall p2;" => Valid::NO,
        "-- error ER_COND_ITEM_TOO_LONG\ncall p3;" => Valid::NO,
        "-- error ER_UNSUPPORTED_PS\ncall p1();" => Valid::NO,
        "-- error ER_STMT_NOT_ALLOWED_IN_SF_OR_TRG\nselect f1(0);" => Valid::NO,
        "-- error ER_STMT_NOT_ALLOWED_IN_SF_OR_TRG\nselect f1(f1(0));" => Valid::NO,
        "-- error ER_STMT_NOT_ALLOWED_IN_SF_OR_TRG\nselect f1(f1(f1(0)));" => Valid::NO,
        "-- error ER_STMT_NOT_ALLOWED_IN_SF_OR_TRG\ninsert into t1 values (0);" => Valid::NO,
        "-- error ER_SP_CURSOR_NOT_OPEN\ncall p();" => Valid::NO,
        "-- error ER_SP_WRONG_NO_OF_FETCH_ARGS\ncall p();" => Valid::NO,
        "-- error ER_PARSE_ERROR\nCREATE TRIGGER tr16 AFTER UPDATE ON t1 FOR EACH ROW INSERT INTO t1 VALUES (1);" => Valid::NO,
        "-- error ER_PARSE_ERROR\nINSERT INTO t1 VALUES (1);" => Valid::NO,
        "-- error ER_PARSE_ERROR\nDELETE FROM t1;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nUPDATE t1 SET a = 1 WHERE a = 1;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nINSERT INTO t2 VALUES (1);" => Valid::NO,
        "-- error ER_PARSE_ERROR\nINSERT INTO th1 VALUES(1);" => Valid::NO,
        "-- error ER_WINDOW_FRAME_ILLEGAL\nEXECUTE p USING @p2, @p1;" => Valid::NO,
        "-- error ER_WINDOW_FRAME_ILLEGAL\nEXECUTE p USING @p1, @p2;" => Valid::NO,
        "-- error ER_WINDOW_FRAME_ILLEGAL\nEXECUTE p USING @p1;" => Valid::NO,
        "-- error ER_WINDOW_FRAME_ILLEGAL\nEXECUTE stmt;" => Valid::NO,
        "-- error 0,ER_UNKNOWN_SYSTEM_VARIABLE\nSET DEBUG = \"\";" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nALTER TABLE t_stmt ADD COLUMN b INT;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nINSERT INTO t1  VALUES (),();" => Valid::NO,
        "-- error ER_PARSE_ERROR\nINSERT INTO t1(c1)  SELECT 1 FROM DUAL;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nLOAD DATA INFILE '../../std_data/loaddata5.dat'\n INTO TABLE t1 FIELDS TERMINATED BY '' ENCLOSED BY '' (c1) ;" => Valid::NO,
        "-- error 0,ER_UNKNOWN_SYSTEM_VARIABLE\nSET @innodb_change_buffering_debug_orig = @@innodb_change_buffering_debug;" => Valid::NO,
        "-- error 0,ER_UNKNOWN_SYSTEM_VARIABLE\nSET GLOBAL innodb_change_buffering_debug = 1;" => Valid::NO,
        "-- error 0, ER_UNKNOWN_SYSTEM_VARIABLE\nSET GLOBAL innodb_change_buffering_debug = 0;" => Valid::NO,
        "-- disable_query_log\n\n\n\n\n-- error 0,ER_UNKNOWN_SYSTEM_VARIABLE\nSET @innodb_change_buffering_debug_orig = @@innodb_change_buffering_debug;" => Valid::NO,
        "-- disable_query_log\n-- error 0, ER_UNKNOWN_SYSTEM_VARIABLE\nSET GLOBAL innodb_change_buffering_debug = @innodb_change_buffering_debug_orig;" => Valid::NO,
        "-- error 0, ER_UNKNOWN_SYSTEM_VARIABLE\nSET GLOBAL innodb_change_buffering_debug = @innodb_change_buffering_debug_orig;" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT @@global.keyring_file_data;" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\ninsert into t1 values('{\"asd\":1}');" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\ninsert into t1 values('true');" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nalter table t2 rename t1, add attr4 int;" => Valid::NO,
        "-- error ER_TOO_LONG_IDENT\nCREATE TABLE t2 (\n  a int\n) ENGINE=NDB;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nPREPARE test_stmt2 FROM @s;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT 'Fail, please', 'a';" => Valid::NO,
        "-- error ER_MASTER_INFO\nRESET SLAVE;" => Valid::NO,
        "-- error ER_CANT_USE_GTID_ONLY_WITH_GTID_MODE_NOT_ON\nSTART SLAVE;" => Valid::NO,
        "-- error ER_MASTER_INFO\nstart slave sql_thread;" => Valid::NO,
        "-- error ER_MASTER_INFO\nstart slave;" => Valid::NO,
        "-- error ER_MASTER_INFO\nRESET SLAVE ALL;" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nCALL p1('test');" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nCALL p2();" => Valid::NO,
        // valid on real DB
        "-- error ER_USER_LOCK_WRONG_NAME\nSELECT STD(IS_FREE_LOCK(0x2ADA5C38)),1 FROM t1 WHERE a+(EXISTS(SELECT 1));" => Valid::NO,
        "-- error 0,ER_NOT_SUPPORTED_YET\nSELECT * FROM (\n  SELECT a, JSON_ARRAYAGG(a) OVER () AS b FROM t1\n) AS d1\nWHERE (a,b) IN (\n  SELECT a, JSON_ARRAYAGG(a) OVER () AS b FROM t1\n);" => Valid::NO,
        "-- error ER_PARSE_ERROR\nCREATE PROCEDURE sp1( )\n BEGIN\n   declare continue handler for sqlstate '02000' set @var2 = 1;\nEND//" => Valid::NO,
        "-- error ER_PARSE_ERROR\nCREATE PROCEDURE sp1( )\n BEGIN\n   declare exit handler for sqlstate '02000' set @var2 = 1;\nEND//" => Valid::NO,
        // binlog
        "-- error ER_SYNTAX_ERROR\nBINLOG '\nDl1YRxMBAAAAKQAAADQBAAAAABAAAAAAAAAABHRlc3QAAnQxAAEDAAE=\nDl1YRxcBAAAAIgAAAFYBAAAQABAAAAAAAAEAAf/+BQAAAA==\n';" => Valid::NO,
        "-- error ER_BASE64_DECODE_ERROR\nBINLOG '123';" => Valid::NO,
        "-- error ER_BASE64_DECODE_ERROR\nBINLOG '-2079193929';" => Valid::NO,
        "-- error ER_BASE64_DECODE_ERROR\nBINLOG 'x├ºΓåô%~ΓêÖDΓòÆ╞ÆΓòí';" => Valid::NO,
        // checks for collation files
        "-- error ER_UNKNOWN_COLLATION\nALTER TABLE t1 ADD COLUMN (j INTEGER);" => Valid::NO,
        "-- error ER_UNKNOWN_COLLATION\nSELECT * FROM t1;" => Valid::NO,
        "-- error ER_UNKNOWN_COLLATION\nINSERT INTO t1 VALUES (1);" => Valid::NO,
        "-- error ER_UNKNOWN_COLLATION\nSHOW CREATE TABLE t1;" => Valid::NO,
        // multiple ORDER BY
        "-- error ER_NOT_SUPPORTED_YET\n((SELECT 1 FROM t1 ORDER BY 1) ORDER BY 1) ORDER BY 1;" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nEXPLAIN ((SELECT * FROM t3 ORDER BY a LIMIT 3)\n            ORDER BY b DESC LIMIT 2)\n                ORDER BY c LIMIT 1;" => Valid::NO,
        "-- error ER_PARSE_ERROR,ER_NOT_SUPPORTED_YET\n((SELECT * FROM t1 ORDER BY i) ORDER BY i) ORDER BY i;" => Valid::NO,
        // multiple LIMIT (OK on real DB)
        "-- error 0,ER_PARSE_ERROR\n((SELECT * FROM t1 LIMIT 1) LIMIT 2) LIMIT 3;" => Valid::NO,
        // operator associativity etc.
        "-- error ER_PARSE_ERROR\nselect TRUE IS TRUE IS TRUE IS TRUE;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nselect FALSE IS NOT TRUE IS NOT TRUE IS NOT TRUE;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nselect NULL IS FALSE IS FALSE IS FALSE;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nselect TRUE IS NOT FALSE IS NOT FALSE IS NOT FALSE;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nselect FALSE IS UNKNOWN IS UNKNOWN IS UNKNOWN;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nselect TRUE IS NOT UNKNOWN IS NOT UNKNOWN IS NOT UNKNOWN;" => Valid::NO,
        // types on aggregate functions
        "-- error ER_PARSE_ERROR\nSELECT id, sex, LEAD(id, -1) RESPECT NULLS OVER () FROM t1;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT id, sex, LEAD(id, 1.2) RESPECT NULLS OVER () FROM t1;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT id, sex, LEAD(id, 'a') RESPECT NULLS OVER () FROM t1;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT id, sex, LEAD(id, NULL) RESPECT NULLS OVER () FROM t1;" => Valid::NO,
        // need to parse prepared statement
        "-- error ER_UNSUPPORTED_PS\nPREPARE stmt1 FROM @sql1;" => Valid::NO,
        "-- error ER_UNSUPPORTED_PS\nPREPARE stmt2 FROM 'SELECT @@warning_count';" => Valid::NO,
        "-- error ER_UNSUPPORTED_PS\nPREPARE stmt2 FROM 'SELECT @@error_count';" => Valid::NO,
        "-- error ER_UNSUPPORTED_PS\nPREPARE stmt FROM \"CREATE TABLE t1 (f1 INT) START TRANSACTION\";" => Valid::NO,
        "-- error ER_TRG_DOES_NOT_EXIST\nexecute stmt;" => Valid::NO,
        // not checking var content on PREPARE
        "-- error ER_PARSE_ERROR\nprepare stmt1 from @nosuchvar;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nprepare stmt1 from @ivar;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nprepare stmt1 from @fvar;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nprepare stmt1 from @arg01;" => Valid::NO,
        // recursion or something...
        "-- error ER_STMT_NOT_ALLOWED_IN_SF_OR_TRG\nselect func_1(), func_1(), func_1() from dual;" => Valid::NO,
        // needs validating charsets
        "-- source include/ctype_filesort.inc\n-- source include/ctype_like_escape.inc\n\n\n\n\n\n\n-- error ER_PARSE_ERROR\nCREATE TABLE \x84a (a int);" => Valid::NO,
        // needs analyzing expressions
        "-- error ER_PARSE_ERROR\nCREATE TABLE t1 (\na int not null,\nb int not null,\nc int not null,\nprimary key(a,b))\npartition by hash (rand(a))\npartitions 2\n(partition x1, partition x2);" => Valid::NO,
        "-- error ER_PARSE_ERROR\nCREATE TABLE t1 (\na int not null,\nb int not null,\nc int not null,\nprimary key(a,b))\npartition by range (rand(a))\npartitions 2\n(partition x1 values less than (0), partition x2 values less than (2));" => Valid::NO,
        "-- error ER_PARSE_ERROR\nCREATE TABLE t1 (\na int not null,\nb int not null,\nc int not null,\nprimary key(a,b))\npartition by list (rand(a))\npartitions 2\n(partition x1 values in (1), partition x2 values in (2));" => Valid::NO,
        "-- error ER_PARSE_ERROR\nCREATE TABLE t1 (\na int not null,\nb int not null,\nc int not null,\nprimary key (a,b))\npartition by key (a)\nsubpartition by hash (rand(a+b));" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table t1 (a int)\npartition by hash (rand(a));" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table t1 (a int)\npartition by hash(CURTIME() + a);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table t1 (a int)\npartition by hash (NOW()+a);" => Valid::NO,
        "-- error ER_PARSE_ERROR\nALTER TABLE t1 ADD PARTITION\n(PARTITION p3_a VALUES IN ((1 + 1 + 1), \"a0\"));" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT CURTIME(-1);" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT SYSDATE(-1);" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT NOW(-1);" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nSELECT SUM(DISTINCT b) OVER () FROM t;" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nselect cast('[1,2,3]' as unsigned array);" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\ncreate table t1 as select cast('[1,2,3]' as unsigned array);" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\ncreate table t(j json, gc json as (cast(j->'$[*]' as unsigned array)));" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\ncreate table t(j json, gc json as\n  ((concat(cast(j->'$[*]' as unsigned array),\"x\"))));" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\ncreate table t1(j json, key i1((cast(j->\"\$\" as json array))));" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\ncreate table t1(j json, key i1((cast(j->\"\$\" as char array))));" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\ncreate table t1(j json, key i1((cast(j->\"\$\" as binary array))));" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\ncreate table t1(j json, key i1((cast(j->\"\$\" as float array))));" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\ncreate table t1(j json, key i1((cast(j->\"\$\" as double array))));" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nCREATE TABLE t1 (f1 json, key mvi((cast(cast(f1 as unsigned array) as unsigned array))));" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nCREATE TABLE t(x INT, KEY k ((1 AND CAST(JSON_ARRAY(X) AS UNSIGNED ARRAY))));" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\ncreate table col(doc json,\n  key i1((cast(doc->'$.text' as char(10) array)),\n         (cast(doc->'$.integer' as signed array))));" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\ncreate table t1 (j json, key mv_idx_char ((cast(j as char(16384) array))));" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\ncreate table t (j json default (cast(json_object() as unsigned array)));" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\ncreate index i1 on t1((cast(f1->\"\$\" as YEAR array)));" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nCREATE TABLE t_copy AS SELECT * FROM t;" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nSELECT JSON_SCHEMA_VALID('{\n  \"type\": \"object\",\n  \"properties\": { \"\$ref\": \"http://example.com\" }\n}','\n{\n  \"latitude\": 63.444697\n}') AS invalid;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT JSON_VALUE('{}', NULL);" => Valid::NO,
        // needs analysing param types
        "-- error ER_PARSE_ERROR\ncreate procedure p1(p1 date, p2 date) select * from t1 limit p1, p2;" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate procedure p1(p1 integer, p2 float) select * from t1 limit p1, p2;" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate procedure p1(p1 integer, p2 char(1)) select * from t1 limit p1, p2;" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate procedure p1(p1 varchar(5), p2 char(1)) select * from t1 limit p1, p2;" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate procedure p1(p1 decimal, p2 decimal) select * from t1 limit p1, p2;" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate procedure p1(p1 double, p2 double) select * from t1 limit p1, p2;" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate function f1(p1 date, p2 date)\n  returns int\nbegin\n  declare a int;\n  set a = (select count(*) from t1 limit p1, p2);\n  return a;\nend;" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate function f1(p1 integer, p2 float)\n  returns int\nbegin\n  declare a int;\n  set a = (select count(*) from t1 limit p1, p2);\n  return a;\nend;" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate function f1(p1 integer, p2 char(1))\n  returns int\nbegin\n  declare a int;\n  set a = (select count(*) from t1 limit p1, p2);\n  return a;\nend;" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate function f1(p1 varchar(5), p2 char(1))\n  returns int\nbegin\n  declare a int;\n  set a = (select count(*) from t1 limit p1, p2);\n  return a;\nend;" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate function f1(p1 decimal, p2 decimal)\n  returns int\nbegin\n  declare a int;\n  set a = (select count(*) from t1 limit p1, p2);\n  return a;\nend;" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate function f1(p1 double, p2 double)\n  returns int\nbegin\n  declare a int;\n  set a = (select count(*) from t1 limit p1, p2);\n  return a;\nend;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT myfunc_int(test.fn(MIN(b) xx)) as c FROM t1 GROUP BY a;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT id, NTILE(NULL) OVER w FROM t1 WINDOW w AS (ORDER BY id);" => Valid::NO,
        "-- error ER_PARSE_ERROR\nEXPLAIN FORMAT=JSON SELECT id, NTILE(NULL) OVER w FROM t1 WINDOW w AS (ORDER BY id);" => Valid::NO,
        "-- error ER_PARSE_ERROR\nDO NTILE(MAX(NOT 1)) OVER();" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT ST_X(ST_POINTFROMWKB(ST_ASWKB(POINT(1))));" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT ST_Y(ST_POINTFROMWKB(ST_ASWKB(POINT(1))));" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT ST_ASTEXT(ST_X(ST_POINTFROMWKB(ST_ASWKB(POINT(1)), 5)));" => Valid::NO,
        "-- error ER_PARSE_ERROR\nSELECT ST_ASTEXT(ST_Y(ST_POINTFROMWKB(ST_ASWKB(POINT(1)), 5)));" => Valid::NO,
        // parse error misuse
        "-- error ER_PARSE_ERROR\nALTER TABLE t1 ADD PARTITION\n(PARTITION p2 VALUES IN ((71),(72),(73),(74),(75),(76),(77),(78),(79),(80),\n                         (81),(82),(83),(84),(85),(86),(87),(88),(89),(90)));" => Valid::NO,
        // conflicting aliases
        "-- error ER_PARSE_ERROR\nDELETE FROM t1 alias USING t1, t2 alias WHERE t1.a = alias.a;" => Valid::NO,
        "-- error ER_UNKNOWN_TABLE\nDELETE FROM t1, t2 USING t1, t2 alias WHERE t1.a = alias.a;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nDELETE FROM db1.t1 alias USING db1.t1, db2.t1 alias WHERE db1.t1.a = alias.a;" => Valid::NO,
        "-- error ER_PARSE_ERROR\nDELETE FROM t1 alias USING t1 alias WHERE a = 2;" => Valid::NO,
        // table + check name
        "-- error ER_TOO_LONG_IDENT\nRENAME TABLE t1 TO t123456789012345678901234567890123456789012345678901234567890;" => Valid::NO,
        "-- error ER_TOO_LONG_IDENT\nCREATE TABLE t123456789012345678901234567890123456789012345678901234567890(f1 INT CHECK(f1 < 10));" => Valid::NO,
        "-- error ER_TOO_LONG_IDENT\nALTER TABLE t123456789012345678901234567890123456789012345678901234567890 ADD CONSTRAINT CHECK (f1 < 10);" => Valid::NO,
        // table + fk name
        "-- error ER_TOO_LONG_IDENT\nRENAME TABLE t2 TO t123456789012345678901234567890123456789012345678901234567;" => Valid::NO,
        "-- error ER_TOO_LONG_IDENT\nCREATE TABLE t123456789012345678901234567890123456789012345678901234567(\n  a INT, FOREIGN KEY (a) REFERENCES t1(a));" => Valid::NO,
        "-- error ER_TOO_LONG_IDENT\nALTER TABLE name567890123456789012345678901234567890123456789012345678901234\nADD FOREIGN KEY(b) REFERENCES t1(a);" => Valid::NO,
        // not checking components
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT @@syseventlog.tag;" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSET GLOBAL syseventlog.include_pid = OFF;" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSET GLOBAL syseventlog.facility = \"local1\";" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSET @save_filters= @@global.dragnet.log_error_filter_rules;" => Valid::NO,
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSET @@global.dragnet.log_error_filter_rules= DEFAULT;" => Valid::NO,
        // depends on plugin
        "-- error ER_UNKNOWN_SYSTEM_VARIABLE\nSELECT @@GLOBAL.validate_password_length;" => Valid::NO,
        // depends on OS
        "-- error ER_FEATURE_UNSUPPORTED\nCREATE RESOURCE GROUP test TYPE=USER VCPU=1-3 THREAD_PRIORITY=5;" => Valid::NO,
        "-- error ER_FEATURE_UNSUPPORTED\nALTER RESOURCE GROUP test VCPU=0;" => Valid::NO,
        "-- error ER_FEATURE_UNSUPPORTED\nDROP RESOURCE GROUP test;" => Valid::NO,
        // scopes & variables
        "-- error ER_VAR_DOES_NOT_EXIST\nRESET PERSIST max_connections;" => Valid::NO,
        "-- error ER_VAR_DOES_NOT_EXIST\nRESET PERSIST sort_buffer_size;" => Valid::NO,
        // NDB
        "-- error ER_NOT_SUPPORTED_YET\nALTER TABLE t1\n  ADD COLUMN c INT,\n  RENAME TO t1_renamed;" => Valid::NO,
        // generated PK vs things
        "-- error ER_NOT_SUPPORTED_YET\nALTER TABLE t1 PARTITION BY KEY(my_row_id) PARTITIONS 10;" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nALTER TABLE t1 DROP COLUMN my_row_id;" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nALTER TABLE t1 DROP PRIMARY KEY, DROP COLUMN my_row_id, ADD UNIQUE KEY(f1);" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nALTER TABLE t2 DROP PRIMARY KEY, DROP COLUMN my_row_id, ADD UNIQUE KEY(f1);" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nALTER TABLE t4 DROP PRIMARY KEY;" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nDROP INDEX `PRIMARY` ON t3;" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nALTER TABLE t2 DROP PRIMARY KEY;" => Valid::NO,
        // partitions on unsupported types
        "-- error ER_NOT_SUPPORTED_YET\nCREATE TABLE t1 (f1 INT, f2 DATE) PARTITION BY KEY(f2) PARTITIONS 2;" => Valid::NO,
        "-- error ER_NOT_SUPPORTED_YET\nCREATE TABLE t1 (f1 INT, f2 INT NOT NULL UNIQUE) PARTITION BY RANGE (f2)\n                   (PARTITION p0 VALUES LESS THAN (2011),\n                    PARTITION p1 VALUES LESS THAN (2022));" => Valid::NO,
        // whitespace dependent function name parsing
        "-- error ER_PARSE_ERROR\ncreate table BIT_AND(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table BIT_OR(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table BIT_XOR(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table CAST(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table COUNT(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table CURDATE(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table CURTIME(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table DATE_ADD(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table DATE_SUB(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table EXTRACT(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table GROUP_CONCAT(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table MAX(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table MID(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table MIN(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table NOW(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table POSITION(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table STD(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table STDDEV(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table STDDEV_POP(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table STDDEV_SAMP(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table SUBSTR(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table SUBSTRING(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table SUM(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table SYSDATE(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table TRIM(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table VARIANCE(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table VAR_POP(a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table VAR_SAMP(a int);" => Valid::NO,
        // with set SQL_MODE='IGNORE_SPACE'
        "-- error ER_PARSE_ERROR\ncreate table BIT_AND (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table BIT_OR (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table BIT_XOR (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table CAST (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table COUNT (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table CURDATE (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table CURTIME (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table DATE_ADD (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table DATE_SUB (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table EXTRACT (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table GROUP_CONCAT (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table MAX (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table MID (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table MIN (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table NOW (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table POSITION (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table STD (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table STDDEV (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table STDDEV_POP (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table STDDEV_SAMP (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table SUBSTR (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table SUBSTRING (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table SUM (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table SYSDATE (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table TRIM (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table VARIANCE (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table VAR_POP (a int);" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate table VAR_SAMP (a int);" => Valid::NO,
        // input validations
        "-- error ER_WRONG_VALUE\nSELECT count(*) FROM t1 WHERE c2='10:45:15' OR c2='2009-01-32' OR c2='2009-02-30' OR c2='2009-04-31' OR c2='2009-06-31' OR c2='2009-09-31' /* returns 0 */;" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT * FROM t1 WHERE c2='0000-00-00';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT * FROM t1 WHERE c1='0000-00-00' OR c2='0000-00-00';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT * FROM t1 WHERE c1='0000-00-00';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT count(*) FROM t1 WHERE c1='2001-01-09 24:59:59' AND c2='2009-01-10 23:60:59';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT count(*) FROM t1 WHERE c2='2001-01-11 23:59:60' /* returns 0 */;" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT * FROM t1 WHERE c1='0000-00-00 00:00:00' OR c2='0000-00-00 00:00:00';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT * FROM t1 WHERE c2='0000-00-00 00:00:00';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nexplain\nselect * from t1 where date_field < '9999-99-99';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nselect * from t1 where date_field < '9999-99-99';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nexplain\nselect * from t1 where date_field > '9999-99-99';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nselect * from t1 where date_field > '9999-99-99';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT * FROM t1 WHERE d <= '2013-02-32';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT * FROM t1 WHERE d <= '2013-02-30';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT * FROM t1 WHERE d >= '0000-00-00';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT * FROM t1 WHERE d >= 'wrong-date';" => Valid::NO,
        "-- error ER_WRONG_VALUE\ncreate event e_26 on schedule at NULL disable do set @a = 5;" => Valid::NO,
        "-- error ER_WRONG_VALUE\ncreate event e_26 on schedule at 'definitely not a datetime' disable do set @a = 5;" => Valid::NO,
        "-- error ER_WRONG_VALUE\ncreate event e_55 on schedule at 99990101000000 do drop table t;" => Valid::NO,
        "-- error ER_WRONG_VALUE\ncreate event e_55 on schedule every 10 hour starts 99990101000000 do drop table t;" => Valid::NO,
        "-- error ER_WRONG_VALUE\ncreate event e_55 on schedule at 10000101000000 do drop table t;" => Valid::NO,
        "-- error ER_WRONG_VALUE\ncreate event e_55 on schedule every 10 hour starts 10000101000000 do drop table t;" => Valid::NO,
        "-- error ER_WRONG_VALUE\nCREATE EVENT new_event ON SCHEDULE AT \"every day\" DO SELECT 1;" => Valid::NO,
        "-- error ER_WRONG_VALUE\nCREATE EVENT new_event ON SCHEDULE AT \"0every day\" DO SELECT 1;" => Valid::NO,
        "-- error ER_WRONG_VALUE\nWITH cte1 AS\n(SELECT(replace(md5(0x9025c5c7),\n                    convert((1) using utf8),\n                    (!(cast((connection_id()) AS char(20)))))) AS a1 FROM t0022)\nSELECT cte1.a1\nFROM cte1 WHERE cte1.a1 = from_unixtime(1537000917);" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT ST_AsWKB(ST_GeomFromText('POINT(0 0)')) > (SELECT b FROM t) AS result;" => Valid::NO,
        "-- error ER_WRONG_VALUE\nALTER USER 'wl7131' PASSWORD EXPIRE INTERVAL 0 DAY;" => Valid::NO,
        "-- error ER_WRONG_VALUE\nEXPLAIN SELECT * FROM t1 WHERE col2 < \"\";" => Valid::NO,
        "-- error ER_WRONG_VALUE\nEXPLAIN SELECT * FROM t1 WHERE a = '0000-00-00';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT * FROM t1 WHERE a = '0000-00-00';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT * FROM t2 WHERE a = '0000-00-00';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nEXPLAIN SELECT * FROM t1 WHERE a = '1000-00-00';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT * FROM t1 WHERE a = '1000-00-00';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nSELECT * FROM t2 WHERE a = '1000-00-00';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nDELETE IGNORE  FROM t1 WHERE dt1 = '0000-00-01 00:00:01';" => Valid::NO,
        // runtime
        "-- error ER_WRONG_VALUE\nCREATE TABLE t3 (id INT) INDEX DIRECTORY = 'test';" => Valid::NO,
        "-- error ER_WRONG_VALUE\nCREATE TABLE t4 (id INT NOT NULL, name VARCHAR(30))\nENGINE = InnoDB\nPARTITION BY RANGE (id) (\nPARTITION p0 VALUES LESS THAN (10) INDEX DIRECTORY = 'test'\n);" => Valid::NO,
        // invalid charsets
        "-- error ER_WRONG_VALUE_FOR_VAR\nset names ucs2;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset names ucs2 collate ucs2_bin;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset character_set_client= ucs2;" => Valid::NO,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset character_set_client= concat('ucs', substr('2', 1));" => Valid::NO,
        // needs table/schema charset context
        "-- error ER_COLLATION_CHARSET_MISMATCH\nSELECT latin1_f,count(*) FROM t1 GROUP BY latin1_f COLLATE koi8r_general_ci;" => Valid::NO,
        "-- error ER_COLLATION_CHARSET_MISMATCH\nSELECT latin1_f COLLATE koi8r_general_ci  AS latin1_f_as FROM t1 ORDER BY latin1_f_as;" => Valid::NO,
        "-- error ER_COLLATION_CHARSET_MISMATCH\nSELECT latin1_f FROM t1 ORDER BY latin1_f COLLATE koi8r_general_ci;" => Valid::NO,
        "-- error ER_COLLATION_CHARSET_MISMATCH\nALTER TABLE t3 CONVERT TO CHARACTER SET DEFAULT COLLATE cp1251_general_cs;" => Valid::NO,
        // types in procedures
        "-- error ER_PARSE_ERROR\ncreate function f1(p1 date, p2 date)\n  returns int\nbegin\n  declare a int;\n  set a = (select count(*) from t1 limit p1, p2);\n  return a;\nend|" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate function f1(p1 integer, p2 float)\n  returns int\nbegin\n  declare a int;\n  set a = (select count(*) from t1 limit p1, p2);\n  return a;\nend|" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate function f1(p1 integer, p2 char(1))\n  returns int\nbegin\n  declare a int;\n  set a = (select count(*) from t1 limit p1, p2);\n  return a;\nend|" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate function f1(p1 varchar(5), p2 char(1))\n  returns int\nbegin\n  declare a int;\n  set a = (select count(*) from t1 limit p1, p2);\n  return a;\nend|" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate function f1(p1 decimal, p2 decimal)\n  returns int\nbegin\n  declare a int;\n  set a = (select count(*) from t1 limit p1, p2);\n  return a;\nend|" => Valid::NO,
        "-- error ER_PARSE_ERROR\ncreate function f1(p1 double, p2 double)\n  returns int\nbegin\n  declare a int;\n  set a = (select count(*) from t1 limit p1, p2);\n  return a;\nend|" => Valid::NO,


        // sometimes fails, depending on context ---------------------------------------------------------------------------------------------------------------------------------------

        "SET GLOBAL replica_parallel_type=@save_replica_parallel_type;" => Valid::SOMETIMES,
        "SET GLOBAL replica_parallel_type= @save_replica_parallel_type;" => Valid::SOMETIMES,
        "SET GLOBAL replica_parallel_workers=@save_replica_parallel_workers;" => Valid::SOMETIMES,
        "SET GLOBAL replica_parallel_workers= @save_replica_parallel_workers;" => Valid::SOMETIMES,
        "SET GLOBAL replica_preserve_commit_order=@save_replica_preserve_commit_order;" => Valid::SOMETIMES,
        "SET GLOBAL replica_preserve_commit_order= @save_replica_preserve_commit_order;" => Valid::SOMETIMES,
        "SET GLOBAL binlog_transaction_dependency_tracking=@save_binlog_transaction_dependency_tracking;" => Valid::SOMETIMES,
        "SET @@global.dragnet.log_error_filter_rules= @rules;" => Valid::SOMETIMES,


        // won't fix - miscellaneous errors not caused by parser implementation --------------------------------------------------------------------------------------------------------

        // invalid variable name (differs from MySQL behavior, which is insane)
        "select @``;" => Valid::YES,
        "select @`endswithspace `;" => Valid::YES,
        "select @X2345678901234567890123456789012345678901234567890123456789012345;" => Valid::YES,

        // wrong perl filtering
        'else { } DROP TABLE t2' => Valid::YES,

        // test artifacts
        "-- error 0\n      ,ER_BLOB_KEY_WITHOUT_LENGTH\n      ,ER_UNSUPPORTED_ACTION_ON_GENERATED_COLUMN\n      ,ER_JSON_USED_AS_KEY\n    ;" => Valid::YES,

        // state emulation fails (probably because not processed includes)
        "set @@ndbinfo_max_bytes = @max_bytes;" => Valid::YES,
        "set @@ndbinfo_max_rows = @max_rows;" => Valid::YES,
        "SET @@global.max_allowed_packet:= @tmp_max;" => Valid::YES,
        "SET @@global.gtid_purged= @gtid_purged_init;" => Valid::YES,

        // invalid hints (ignored by MySQL)
        "SELECT /*+ SET_VAR(foo = 1K) */ 1;" => Valid::YES,
        "SELECT /*+ SET_VAR(bar = 'baz') */ 1;" => Valid::YES,
        "SELECT /*+ NO_ICP() */ 1\n  FROM /*+ regular commentary, not a hint! */ t1;" => Valid::YES, // NO_ICP should have params!
        "(SELECT 1) UNION (SELECT /*+ NO_ICP() */ 1);" => Valid::YES,
        "SELECT /*+ NO_ICP(t1 ( */ 1;" => Valid::YES,
        "SELECT /*+ NO_ICP(t1 */ 1;" => Valid::YES,
        "SELECT /*+ NO_ICP) */ 1;" => Valid::YES,
        "SELECT /*+ NO_ICP( */ 1;" => Valid::YES,
        "SELECT /*+ NO_ICP(10) */ 1;" => Valid::YES,
        "SELECT /*+ NO_ICP() */ 1;" => Valid::YES,
        "EXPLAIN SELECT /*+ QB_NAME(``) */ 1;" => Valid::YES,
        "SELECT /*+ BKA(a b) */   1 FROM t1 a, t1 b;" => Valid::YES,
        "DELETE  /*+ NO_ICP() */ FROM t1 WHERE 1;" => Valid::YES,
        "REPLACE /*+ NO_ICP() */ INTO t1 VALUES ();" => Valid::YES,
        "INSERT  /*+ NO_ICP() */ INTO t1 VALUES ();" => Valid::YES,
        "UPDATE  /*+ NO_ICP() */ t1 SET i = 10;" => Valid::YES,
        "(SELECT /*+ NO_ICP() */ 1) UNION (SELECT 1);" => Valid::YES,
        "SELECT  /*+ NO_ICP() */ 1 UNION SELECT 1;" => Valid::YES,
        "SELECT  /*+ NO_ICP (  ) */ 1;" => Valid::YES,
        "SELECT  /*+ NO_ICP () */ 1;" => Valid::YES,
        "SELECT  /*+NO_ICP()*/ 1;" => Valid::YES,
        "SELECT  /*+ NO_ICP() */ 1;" => Valid::YES,
        "SELECT /*+ BKA(t1 @) */ 1;" => Valid::YES,
        "SELECT /*+ BKA( @) */ 1;" => Valid::YES,
        "SELECT /*+ SET_VAR(foo = 'test') */ 1;" => Valid::YES,
        "SELECT /*+ SET_VAR(foo = 10) */ 1;" => Valid::YES,
        "SELECT /*+ SET_VAR(foo = 21M) */ 1;" => Valid::YES,
        "SELECT /*+ SET_VAR(foo = 321G) */ 1;" => Valid::YES,
        "SELECT /*+ SET_VAR(foo = 9000100500G) */ 1;" => Valid::YES,
        "SELECT /*+ SET_VAR(foo = \"test\"\"test\") */ 1;" => Valid::YES,
        "SELECT /*+ SET_VAR(foo = 900010050018247362846826482468) */ 1;" => Valid::YES,
        "SELECT /*+ SET_VAR(foo = 900010050018247362846826482468000) */ 1;" => Valid::YES,
        "explain SELECT /*+ SET_VAR(max_allowed_packet = 1M) */ * FROM t1;" => Valid::YES,
        "explain SELECT /*+ SET_VAR(optimizer_switc = 'batched_key_access=off') */ * FROM t1;" => Valid::YES,
        "explain SELECT /*+ SET_VAR(optimizer_switch = 'batched_key_acces=off') SET_VAR(range_alloc_block_size=amba)*/ * FROM t1;" => Valid::YES,
        "EXPLAIN SELECT /*+ SET_VAR(max_error_count=0) SET_VAR(optimizer_switch = 'batched_key_acces=off') SET_VAR(range_alloc_block_size=amba)*/ * FROM t1;" => Valid::YES,
        "EXPLAIN\nSELECT /*+ SUBQUERY(@subq1 FIRSTMATCH) SUBQUERY(@subq2 LOOSESCAN) */ *\nFROM t3\nWHERE t3.a IN (SELECT /*+ QB_NAME(subq1) */ a FROM t1 tx)\n  AND t3.b IN (SELECT /*+ QB_NAME(subq2) */ a FROM t1 ty);" => Valid::YES,
        "EXPLAIN\nSELECT /*+ SUBQUERY(@subq1 MATERIALIZATION, INTOEXISTS)\n       SUBQUERY(@subq2 MATERIALIZATION, INTOEXISTS) */ *\nFROM t3\nWHERE t3.a IN (SELECT /*+ QB_NAME(subq1) */ a FROM t1 tx)\n  AND t3.b IN (SELECT /*+ QB_NAME(subq2) */ a FROM t1 ty);" => Valid::YES,
        "EXPLAIN\nSELECT /*+ SEMIJOIN(@subq1 INTOEXISTS) NO_SEMIJOIN(@subq2 INTOEXISTS) */ *\nFROM t1\nWHERE t1.a IN (SELECT /*+ QB_NAME(subq1) */ a FROM t3)\n  AND t1.b IN (SELECT /*+ QB_NAME(subq2) */ a FROM t2);" => Valid::YES,
        "EXPLAIN SELECT * FROM\n  (SELECT /*+ QB_NAME(qb1) BKA(@qb1 t1@qb1, t2@qb1, t3) */ t2.f1, t2.f2, t2.f3 FROM t1,t2,t3) tt;" => Valid::YES,
        "EXPLAIN SELECT /*+ BKA(qb1 t3@qb1) */ f2 FROM\n  (SELECT /*+ QB_NAME(qb1) */ f2, f3, f1 FROM t3 WHERE f1 > 2 AND f3 = 'poiu') AS TD\n    WHERE TD.f1 > 2 AND TD.f3 = 'poiu';" => Valid::YES,
        "select /*+ INDEX_MERGE( t , a ) */ a from t where a ='2016-11-11' and a ='65525'  ;" => Valid::YES,
        "select /*+ JOIN_FIXED_ORDER(qb2 / */ a from t where a ='255' and a =1  ;" => Valid::YES,
        "select /*+ JOIN_FIXED_ORDER(qb2 / */ a from t where a =255  ;" => Valid::YES,
        "select /*+ SUBQUERY(INTOEXISTS,MATERIALIZATION ) */ a from t where a ='65525' and a =1  ;" => Valid::YES,

        "SELECT /*+ BKA(\" quoted name тест\") */ 1 FROM t1;" => Valid::SOMETIMES,
        "-- error ER_PARSE_ERROR\nSELECT /*+ BKA(`test*/`) */ 1;" => Valid::NO,

        // invalid test code
        "REVOKE abc ON *.* FROM testuser@localhost;" => Valid::YES,
        "REVOKE abc ON *.* FROM testrole;" => Valid::YES,
        "REVOKE engineering ON *.* FROM joan, sally;" => Valid::YES,
        "REVOKE wp_administrators, engineering ON *.* FROM joan, sally;" => Valid::YES,

        // real syntax errors
        "CREATE TABLE t (\n    i  int NOT NULL AUTO_INCREMENT,\n    mt mediumtext NOT NULL,\n    c  varchar(10) NOT NULL,\n    ti tinyint(1) unsigned NOT NULL,\n    PRIMARY KEY (i, ti)\n  )\n  ENGINE = InnoDB AUTO_INCREMENT = 0\n  DEFAULT CHARSET = latin1, DATA DIRECTORY = '/tmp'\n  PARTITION BY LIST (ti) (\n    PARTITION p0 VALUES IN (0) ENGINE = InnoDB,\n    PARTITION p1 VALUES IN (1) DATA DIRECTORY = '/tmp' ,ENGINE = InnoDB\n  );" => Valid::YES, // syntax error near ENGINE at the end
        "PREPARE stmt FROM \"SELECT w, SUM(w) OVER (ROWS 3.14 PRECEDING) FROM t\";" => Valid::YES, // will fail on EXECUTE
        "CREATE TABLE empty (pri int(11) NOT NULL) ENGINE=NDB;" => Valid::YES, // invalid name
        "DROP TABLE empty;" => Valid::YES, // invalid name
        "DROP PROCEDURE sp1_thisisaveryverylongname234872934_thisisaveryverylongname234872934;" => Valid::YES, // name too long
        "DROP PROCEDURE sp1_thisisaveryverylongname234872934_thisisaveryverylongnameabcde;" => Valid::YES, // name too long
        "CREATE TABLESPACE ts1\n  ADD DATAFILE 'ts1_datafile.dat'\n  USE LOGFILE GROUP lg1\n  ENGINE=NDB ENCRYPTION='';" => Valid::YES, // invalid encryption
        "-- error ER_CHECK_NOT_IMPLEMENTED\nCREATE TABLESPACE ts1\n  ADD DATAFILE 'ts1_datafile.dat'\n  USE LOGFILE GROUP lg1\n  ENGINE=NDB ENCRYPTION='R';" => Valid::YES, // invalid encryption
        "-- error ER_TABLESPACE_MISSING_WITH_NAME\nDROP TABLESPACE s-- error ER_PARSE_ERROR\nDROP TABLESPACE s@bad;" => Valid::YES, // invalid test code: s#bad\n;

        // non-existing algorithms
        "CREATE TABLE t1(c1 INT PRIMARY KEY) COMPRESSION=\"zlibX\";" => Valid::YES,
        "ALTER TABLE t1 COMPRESSION='abcdefghijklmnopqrstuvwxyz';" => Valid::YES,

        // non-existing storage engines
        "ALTER TABLE t2 ENGINE=example;" => Valid::YES,
        "CREATE TABLE t_stmt (a VARCHAR(100)) ENGINE = EXAMPLE;" => Valid::YES,
        "CREATE TABLE t_slave_stmt (a INT) ENGINE = EXAMPLE;" => Valid::YES,
        "CREATE TABLE t7 (c1 INT) ENGINE= EXAMPLE;" => Valid::YES,
        "CREATE TABLE t1(a int) ENGINE=EXAMPLE;" => Valid::YES,
        "CREATE TABLE t10(a INT) ENGINE=EXAMPLE;" => Valid::YES,
        "CREATE TABLE t20(a INT) ENGINE=EXAMPLE;" => Valid::YES,
        "-- error ER_DISABLED_STORAGE_ENGINE\nCREATE TABLE t8 (c1 INT) ENGINE= EXAMPLE;" => Valid::YES,
        "-- error ER_DISABLED_STORAGE_ENGINE\nALTER TABLE t2 ENGINE=example;" => Valid::YES,
        "-- error ER_DISABLED_STORAGE_ENGINE\nCREATE TABLE t1(a int) ENGINE=EXAMPLE;" => Valid::YES,
        "-- error ER_BINLOG_ROW_MODE_AND_STMT_ENGINE\nCREATE TABLE t_stmt_new ENGINE = EXAMPLE SELECT * FROM t_stmt;" => Valid::YES,
        "CREATE TABLE t1 (a INT)\nENGINE=NonExistentEngine;" => Valid::YES,
        "CREATE TABLE t1 (a INT)\nENGINE=NonExistentEngine\nPARTITION BY HASH (a);" => Valid::YES,
        "ALTER TABLE t1 ENGINE=NonExistentEngine;" => Valid::YES,
        "ALTER TABLE t1\nPARTITION BY HASH (a)\n(PARTITION p0 ENGINE=InnoDB,\n PARTITION p1 ENGINE=NonExistentEngine);" => Valid::YES,
        "-- error ER_TOO_MANY_KEYS\nCREATE TABLE t1 (a int PRIMARY KEY) ENGINE=EXAMPLE;" => Valid::YES,
        "-- error ER_TOO_MANY_KEYS\nCREATE TABLE t1 (a int, KEY (a)) ENGINE=EXAMPLE;" => Valid::YES,
        "CREATE TABLE t1(a INT, b TEXT, KEY (a)) SECONDARY_ENGINE=MOCK;" => Valid::YES,

        // non-existing variables
        "-- error ER_WRONG_TYPE_FOR_VAR\nSET GLOBAL example_signed_long_var = -9223372036854775809;" => Valid::YES,
        "-- error ER_WRONG_TYPE_FOR_VAR\nSET GLOBAL example_signed_longlong_var = -9223372036854775809;" => Valid::YES,
        "-- error ER_WRONG_TYPE_FOR_VAR\nSET SESSION example_signed_long_thdvar = -9223372036854775809;" => Valid::YES,
        "-- error ER_WRONG_TYPE_FOR_VAR\nSET SESSION example_signed_longlong_thdvar = -9223372036854775809;" => Valid::YES,
        "-- error ER_WRONG_VALUE_FOR_VAR\nSET GLOBAL example_enum_var= impossible;" => Valid::YES,
        "-- error ER_WRONG_VALUE_FOR_VAR\nset global example_ulong_var=1111;" => Valid::YES,
        "SELECT @@GLOBAL.example_double_var;" => Valid::YES,
        "SELECT @@GLOBAL.example_signed_int_var;" => Valid::YES,
        "SELECT @@GLOBAL.example_signed_long_var IN (-2147483648, -9223372036854775808);" => Valid::YES,
        "SELECT @@GLOBAL.example_signed_long_var IN (2147483647, 9223372036854775807);" => Valid::YES,
        "SELECT @@GLOBAL.example_signed_long_var;" => Valid::YES,
        "SELECT @@GLOBAL.example_signed_longlong_var;" => Valid::YES,
        "SELECT @@SESSION.example_create_count_thdvar;" => Valid::YES,
        "SELECT @@SESSION.example_double_thdvar;" => Valid::YES,
        "SELECT @@SESSION.example_last_create_thdvar;" => Valid::YES,
        "SELECT @@SESSION.example_signed_int_thdvar;" => Valid::YES,
        "SELECT @@SESSION.example_signed_long_thdvar IN (-2147483648, -9223372036854775808);" => Valid::YES,
        "SELECT @@SESSION.example_signed_long_thdvar IN (2147483647, 9223372036854775807);" => Valid::YES,
        "SELECT @@SESSION.example_signed_long_thdvar;" => Valid::YES,
        "SELECT @@SESSION.example_signed_longlong_thdvar;" => Valid::YES,
        "SELECT @@global.example_enum_var = 'e2';" => Valid::YES,
        "SET GLOBAL example_double_var = -0.1;" => Valid::YES,
        "SET GLOBAL example_double_var = 0.000001;" => Valid::YES,
        "SET GLOBAL example_double_var = 0.4;" => Valid::YES,
        "SET GLOBAL example_double_var = 1000.51;" => Valid::YES,
        "SET GLOBAL example_double_var = 123.456789;" => Valid::YES,
        "SET GLOBAL example_double_var = 500;" => Valid::YES,
        "SET GLOBAL example_double_var = 999.999999;" => Valid::YES,
        "SET GLOBAL example_enum_var= e1;" => Valid::YES,
        "SET GLOBAL example_enum_var= e2;" => Valid::YES,
        "SET GLOBAL example_signed_int_var = -100;" => Valid::YES,
        "SET GLOBAL example_signed_int_var = -2147483648;" => Valid::YES,
        "SET GLOBAL example_signed_int_var = -2147483649;" => Valid::YES,
        "SET GLOBAL example_signed_int_var = 0;" => Valid::YES,
        "SET GLOBAL example_signed_int_var = 100;" => Valid::YES,
        "SET GLOBAL example_signed_int_var = 2147483647;" => Valid::YES,
        "SET GLOBAL example_signed_int_var = 2147483648;" => Valid::YES,
        "SET GLOBAL example_signed_long_var = -100;" => Valid::YES,
        "SET GLOBAL example_signed_long_var = -9223372036854775808;" => Valid::YES,
        "SET GLOBAL example_signed_long_var = -9223372036854775809;" => Valid::YES,
        "SET GLOBAL example_signed_long_var = 0;" => Valid::YES,
        "SET GLOBAL example_signed_long_var = 100;" => Valid::YES,
        "SET GLOBAL example_signed_long_var = 9223372036854775807;" => Valid::YES,
        "SET GLOBAL example_signed_long_var = 9223372036854775808;" => Valid::YES,
        "SET GLOBAL example_signed_longlong_var = -100;" => Valid::YES,
        "SET GLOBAL example_signed_longlong_var = -9223372036854775808;" => Valid::YES,
        "SET GLOBAL example_signed_longlong_var = -9223372036854775809;" => Valid::YES,
        "SET GLOBAL example_signed_longlong_var = 0;" => Valid::YES,
        "SET GLOBAL example_signed_longlong_var = 100;" => Valid::YES,
        "SET GLOBAL example_signed_longlong_var = 9223372036854775807;" => Valid::YES,
        "SET GLOBAL example_signed_longlong_var = 9223372036854775808;" => Valid::YES,
        "SET SESSION example_create_count_thdvar = 0;" => Valid::YES,
        "SET SESSION example_double_thdvar = -0.1;" => Valid::YES,
        "SET SESSION example_double_thdvar = 0.000001;" => Valid::YES,
        "SET SESSION example_double_thdvar = 0.4;" => Valid::YES,
        "SET SESSION example_double_thdvar = 1000.51;" => Valid::YES,
        "SET SESSION example_double_thdvar = 123.456789;" => Valid::YES,
        "SET SESSION example_double_thdvar = 500;" => Valid::YES,
        "SET SESSION example_double_thdvar = 999.999999;" => Valid::YES,
        "SET SESSION example_last_create_thdvar = '';" => Valid::YES,
        "SET SESSION example_signed_int_thdvar = -100;" => Valid::YES,
        "SET SESSION example_signed_int_thdvar = -2147483648;" => Valid::YES,
        "SET SESSION example_signed_int_thdvar = -2147483649;" => Valid::YES,
        "SET SESSION example_signed_int_thdvar = 0;" => Valid::YES,
        "SET SESSION example_signed_int_thdvar = 100;" => Valid::YES,
        "SET SESSION example_signed_int_thdvar = 2147483647;" => Valid::YES,
        "SET SESSION example_signed_int_thdvar = 2147483648;" => Valid::YES,
        "SET SESSION example_signed_long_thdvar = -100;" => Valid::YES,
        "SET SESSION example_signed_long_thdvar = -9223372036854775808;" => Valid::YES,
        "SET SESSION example_signed_long_thdvar = -9223372036854775809;" => Valid::YES,
        "SET SESSION example_signed_long_thdvar = 0;" => Valid::YES,
        "SET SESSION example_signed_long_thdvar = 100;" => Valid::YES,
        "SET SESSION example_signed_long_thdvar = 9223372036854775807;" => Valid::YES,
        "SET SESSION example_signed_long_thdvar = 9223372036854775808;" => Valid::YES,
        "SET SESSION example_signed_longlong_thdvar = -100;" => Valid::YES,
        "SET SESSION example_signed_longlong_thdvar = -9223372036854775808;" => Valid::YES,
        "SET SESSION example_signed_longlong_thdvar = -9223372036854775809;" => Valid::YES,
        "SET SESSION example_signed_longlong_thdvar = 0;" => Valid::YES,
        "SET SESSION example_signed_longlong_thdvar = 100;" => Valid::YES,
        "SET SESSION example_signed_longlong_thdvar = 9223372036854775807;" => Valid::YES,
        "SET SESSION example_signed_longlong_thdvar = 9223372036854775808;" => Valid::YES,
        "select @@global.example_ulong_var;" => Valid::YES,
        "set global example_enum_var= e1;" => Valid::YES,
        "set global example_ulong_var=1111;" => Valid::YES,
        "set global example_ulong_var=500;" => Valid::YES,
        "-- error ER_PERSIST_ONLY_ACCESS_DENIED_ERROR\nSET PERSIST_ONLY test_component.sensitive_ro_string_1 = 'haha';" => Valid::YES,
        "-- error ER_PERSIST_ONLY_ACCESS_DENIED_ERROR\nSET PERSIST_ONLY test_component.sensitive_ro_string_2 = 'hoho';" => Valid::YES,
        "-- error ER_PERSIST_ONLY_ACCESS_DENIED_ERROR\nSET PERSIST_ONLY test_component.sensitive_ro_string_3 = 'hehe';" => Valid::YES,
        "-- error ER_PERSIST_ONLY_ACCESS_DENIED_ERROR\nSET PERSIST_ONLY test_component.sensitive_string_1 = 'haha';" => Valid::YES,
        "-- error ER_PERSIST_ONLY_ACCESS_DENIED_ERROR\nSET PERSIST_ONLY test_component.sensitive_string_2 = 'hoho';" => Valid::YES,
        "-- error ER_PERSIST_ONLY_ACCESS_DENIED_ERROR\nSET PERSIST_ONLY test_component.sensitive_string_3 = 'hehe';" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSELECT @@global.test_component.sensitive_ro_string_1;" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSELECT @@global.test_component.sensitive_string_1;" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSELECT @@session.test_component.sensitive_ro_string_1;" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSELECT @@session.test_component.sensitive_string_1;" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSET GLOBAL test_component.sensitive_string_1 = 'haha';" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSET GLOBAL test_component.sensitive_string_2 = 'hoho';" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSET GLOBAL test_component.sensitive_string_3 = 'hehe';" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSET PERSIST test_component.sensitive_string_1 = 'haha';" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSET PERSIST test_component.sensitive_string_2 = 'hoho';" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSET PERSIST test_component.sensitive_string_3 = 'hehe';" => Valid::YES,
        "SELECT @@global.test_component.sensitive_ro_string_1;" => Valid::YES,
        "SELECT @@global.test_component.sensitive_string_1;" => Valid::YES,
        "SET GLOBAL test_component.sensitive_string_1 = 'haha';" => Valid::YES,
        "SET PERSIST test_component.sensitive_string_1 = 'haha';" => Valid::YES,
        "SET PERSIST_ONLY test_component.sensitive_string_1 = 'haha';" => Valid::YES,
        "SET PERSIST_ONLY test_component.sensitive_ro_string_1 = 'haha';" => Valid::YES,
        "SET GLOBAL test_component.sensitive_string_1 = \"haha\";" => Valid::YES,
        "SET PERSIST test_component.sensitive_string_2 = \"haha\";" => Valid::YES,
        "SET @@test_security_context_get_field = \"user\", @@test_security_context_get_value = \"root\";" => Valid::YES,
        "SET @@test_security_context_get_field = \"user\", @@test_security_context_get_value = \"root-err\";" => Valid::YES,
        "SET @@test_security_context_get_field = \"host\", @@test_security_context_get_value = \"localhost\";" => Valid::YES,
        "SET @@test_security_context_get_field = \"ip\";" => Valid::YES,
        "SET @@test_security_context_get_field = \"priv_user\", @@test_security_context_get_value = \"root\";" => Valid::YES,
        "SET @@test_security_context_get_field = \"priv_host\", @@test_security_context_get_value = \"localhost\";" => Valid::YES,
        "SET @@test_security_context_get_field = \"sec_ctx_test\";" => Valid::YES,
        "SET GLOBAL example_ulong_var = 100;" => Valid::YES,
        "SET GLOBAL example_enum_var = e1;" => Valid::YES,
        "SET GLOBAL example_double_var = 100.9990;" => Valid::YES,
        "SET GLOBAL example_double_thdvar = 101.9991;" => Valid::YES,
        "SET SESSION example_double_thdvar = 102.9992;" => Valid::YES,
        "SET GLOBAL example_ulong_var = 200;" => Valid::YES,
        "SET GLOBAL example_enum_var = e2;" => Valid::YES,
        "SET GLOBAL example_double_var = 200.8880;" => Valid::YES,
        "SET GLOBAL example_double_thdvar = 201.8881;" => Valid::YES,
        "SET SESSION example_double_thdvar = 202.8882;" => Valid::YES,
        "SET GLOBAL example_ulong_var = 300;" => Valid::YES,
        "SET GLOBAL example_double_var = 301.0000;" => Valid::YES,
        "SET GLOBAL example_double_thdvar = 302.0000;" => Valid::YES,
        "SET SESSION example_double_thdvar = 300.0000;" => Valid::YES,
        "SET SESSION example_double_thdvar = 300.1111;" => Valid::YES,
        "SET SESSION example_double_thdvar = 300.2222;" => Valid::YES,
        "SET SESSION example_double_thdvar = 300.3333;" => Valid::YES,
        "SET SESSION example_double_thdvar = 311.1111;" => Valid::YES,
        "SET SESSION example_double_thdvar = 322.2222;" => Valid::YES,
        "SET SESSION example_double_thdvar = 333.3333;" => Valid::YES,
        "SELECT @@test_component.int_sys_var;" => Valid::YES,
        "SELECT @@global.test_component.int_sys_var;" => Valid::YES,
        "SELECT @@global.test_component.bool_sys_var;" => Valid::YES,
        "SELECT @@test_component.int_sys_var, @@test_component.bool_sys_var;" => Valid::YES,
        "SET GLOBAL test_component.int_sys_var=7;" => Valid::YES,
        "SET GLOBAL test_component.int_sys_var=1234567;" => Valid::YES,
        "SET GLOBAL test_component.int_sys_var=-1;" => Valid::YES,
        "SET GLOBAL test_component.int_sys_var=123, test_component.bool_sys_var=0;" => Valid::YES,
        "-- error ER_GLOBAL_VARIABLE\nSET SESSION test_component.int_sys_var=123;" => Valid::YES,
        "SELECT @@test_component.enum_sys_var;" => Valid::YES,
        "SET GLOBAL test_component.enum_sys_var=\"LOW\";" => Valid::YES,
        "SELECT @@test_component.str_sys_var;" => Valid::YES,
        "SET GLOBAL test_component.str_sys_var=\"dictionary.txt\";" => Valid::YES,
        "SET GLOBAL test_component.str_sys_var=default;" => Valid::YES,
        "SELECT @@test_component.uint_sys_var;" => Valid::YES,
        "SET GLOBAL test_component.uint_sys_var=12345678;" => Valid::YES,
        "SET GLOBAL test_component.uint_sys_var=default;" => Valid::YES,
        "SELECT @@test_component.long_sys_var;" => Valid::YES,
        "SET GLOBAL test_component.long_sys_var=1234567890;" => Valid::YES,
        "SET GLOBAL test_component.long_sys_var=default;" => Valid::YES,
        "SELECT @@test_component.ulong_sys_var;" => Valid::YES,
        "SET GLOBAL test_component.ulong_sys_var=1234567890;" => Valid::YES,
        "SET GLOBAL test_component.ulong_sys_var=default;" => Valid::YES,
        "SELECT @@test_component.longlong_sys_var;" => Valid::YES,
        "SET GLOBAL test_component.longlong_sys_var=1234567890;" => Valid::YES,
        "SET GLOBAL test_component.longlong_sys_var=default;" => Valid::YES,
        "SELECT @@test_component.ulonglong_sys_var;" => Valid::YES,
        "SET GLOBAL test_component.ulonglong_sys_var=1234567890;" => Valid::YES,
        "SET GLOBAL test_component.ulonglong_sys_var=default;" => Valid::YES,
        "SET PERSIST test_component.int_sys_var=7;" => Valid::YES,
        "RESET PERSIST `test_component.int_sys_var`;" => Valid::YES,
        "SET GLOBAL test_component.str_sys_var=\"salve.txt\";" => Valid::YES,
        "SET GLOBAL test_component_str.str_sys_var=\"salve.txt\";" => Valid::YES,
        "SELECT @@test_component_str.str_sys_var;" => Valid::YES,
        "CREATE PROCEDURE p1(x VARCHAR(32)) SET @@GLOBAL.test_component.str_sys_var = x;" => Valid::YES,
        "CREATE PROCEDURE p2() SELECT @@test_component.str_sys_var;" => Valid::YES,
        "SET GLOBAL test_component_str.str_sys_var=\"dictionary.txt\";" => Valid::YES,
        "SET GLOBAL test_component_str.str_sys_var=default;" => Valid::YES,
        "SELECT @@test_component_int.uint_sys_var;" => Valid::YES,
        "SET GLOBAL test_component_int.uint_sys_var=12345678;" => Valid::YES,
        "SET GLOBAL test_component_int.uint_sys_var=default;" => Valid::YES,
        "SELECT @@test_component_int.int_sys_var;" => Valid::YES,
        "SET GLOBAL test_component_int.int_sys_var=12345678;" => Valid::YES,
        "SET GLOBAL test_component_int.int_sys_var=default;" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSET GLOBAL test_component_str.str_sys_var=\"dictionary.txt\";" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSET GLOBAL test_component.long_sys_var=1234567890;" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSET GLOBAL test_component.ulong_sys_var=1234567890;" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSET GLOBAL test_component.longlong_sys_var=1234567890;" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSET GLOBAL test_component_int.uint_sys_var=12345678;" => Valid::YES,
        "-- error ER_SPECIFIC_ACCESS_DENIED_ERROR\nSET GLOBAL test_component_int.int_sys_var=12345678;" => Valid::YES,
        "SET GLOBAL test_component.str_sys_var=\"Before crash\";" => Valid::YES,
        "SET GLOBAL test_component.int_sys_var=123;" => Valid::YES,
    ];

}
